import React, { Component } from 'react';
import PropTypes from 'prop-types';

import '../styles';
import Icon from './Icon';
import icons from '../libs/fontawesome-5.2.0/metadata/icons.json';

class IconChooser extends Component {
    static propTypes = {
        onClick: PropTypes.func,
        textSearch: PropTypes.string,
        grid: PropTypes.oneOfType([
            PropTypes.string,
            PropTypes.number,
        ]),
        style: PropTypes.object,
        iconStyle: PropTypes.object,
    }

    static defaultProps = {
        textSearch: '',
        grid: 6,
        style: { width: '100%', height: '100%' },
        iconStyle: {},
    }

    handlers = {
        onClick: (icon) => {
            const { onClick } = this.props;
            if (onClick) {
                onClick(icon);
            }
        },
    }

    getPrefix = (style) => {
        let prefix = 'fas';
        if (style === 'brands') {
            prefix = 'fab';
        } else if (style === 'regular') {
            prefix = 'far';
        }
        return prefix;
    }

    getIcons = (textSearch) => {
        const lowerCase = textSearch.toLowerCase();
        return Object.keys(icons)
            .filter(icon => icon.includes(lowerCase) || icons[icon].search.terms.some(term => term.includes(lowerCase)))
            .map(icon => ({ [icon]: icons[icon] }));
    }

    render() {
        const { onClick } = this.handlers;
        const { textSearch, grid, style, iconStyle } = this.props;
        const filteredIcons = this.getIcons(textSearch);
        const newIconStyle = {
            ...iconStyle,
            width: `${100 / grid}%`,
        };
        return (
            <div style={style}>
                {
                    filteredIcons.map((ic) => {
                        const name = Object.keys(ic)[0];
                        const metadata = ic[name];
                        const prefix = this.getPrefix(metadata.styles[0]);
                        return (
                            <div className="rfl-icon" style={newIconStyle} onClick={onClick.bind(this, ic)} key={name}>
                                <div className="rfl-icon-top">
                                    <Icon name={name} size={3} prefix={prefix} />
                                </div>
                                <div className="rfl-icon-bottom">
                                    {name}
                                </div>
                            </div>
                        );
                    })
                }
            </div>
        );
    }
}

export default IconChooser;
